/*----------------------------------------------------------*/
/*    Copyright (C) Siemens AG (1999). All Rights Reserved	*/
/*    Product:          SIMATIC PDM							*/
/*                                                          */
/*    Device:           P&F LB/FB-REMOTE IO                 */
/*    Description:      Thermoelement Meumformer			*/
/*												            */
/*    Dictionary:       PFDP_DC_V6.dct                      */
/*                                                          */
/*  $Revision:   1.23  $                                    */
/*  $Date:   06 Apr 2000 12:47:48  $                        */
/*----------------------------------------------------------*/


#define		SENSOR_TC_UNIT_C							\
			(TempTC_P1_Option_Temperatur == 0)			\

#define		SENSOR_TC_UNIT_F							\
			(TempTC_P1_Option_Temperatur != 0)			\


#define		SENSOR_TC_VOLT								\
			(TempTC_P1_Mode == 0x0000)					\

#define		SENSOR_TC_TEMP								\
			(TempTC_P1_Mode != 0x0000)					\


#define		TempTC_CALC(TempVal_TTTC)				\
			IF (SENSOR_TC_UNIT_C)						\
			{											\
				TempVal_TTTC;							\
			}											\
			ELSE										\
			{											\
				(TempVal_TTTC * 1.8) + 32.0;			\
			}

#define		VoltTC_CALC

#define		TempTC_MB_ME_MIN_VALUES						\
			IF (SENSOR_TC_UNIT_C)						\
			{											\
				SELECT (TempTC_P1_Mode) /*Celsius*/		\
				{										\
					CASE 0:		-75.000;	/*linear*/	\
					CASE 1:		-200.000;				\
					CASE 2:		0.000;					\
					CASE 3:		-270.000;				\
					CASE 4:		-270.000;				\
					CASE 5:		-200.000;				\
					CASE 6:		0.000;					\
					CASE 7:		-200.000;				\
					CASE 8:		-50.000;				\
					CASE 9:		-210.000;				\
					CASE 10:	-210.000;				\
					CASE 11:	-100.000;				\
				}										\
			}											\
			ELSE										\
			{											\
				SELECT (TempTC_P1_Mode) /*Fahrenheit*/	\
				{										\
					CASE 0:		-75.000;	/*linear*/	\
					CASE 1:		-328.000;				\
					CASE 2:		32.000;					\
					CASE 3:		-454.000;				\
					CASE 4:		-454.000;				\
					CASE 5:		-328.000;				\
					CASE 6:		32.000;					\
					CASE 7:		-328.000;				\
					CASE 8:		-58.000;				\
					CASE 9:		-346.000;				\
					CASE 10:	-346.000;				\
					CASE 11:	-148.000;				\
				}										\
			}


#define		TempTC_MB_ME_MAX_VALUES					  	\
			IF (SENSOR_TC_UNIT_C)						\
			{											\
				SELECT (TempTC_P1_Mode) /*Celsius*/		\
				{										\
					CASE 0:		75.000;	/*linear*/		\
					CASE 1:		600.000;				\
					CASE 2:		1820.000;				\
					CASE 3:		1000.000;				\
					CASE 4:		400.000;				\
					CASE 5:		1370.000;				\
					CASE 6:		1760.000;				\
					CASE 7:		900.000;				\
					CASE 8:		1760.000;				\
					CASE 9:		1200.000;				\
					CASE 10:	1200.000;				\
					CASE 11:	1300.000;				\
				}										\
			}											\
			ELSE										\
			{											\
				SELECT (TempTC_P1_Mode) /*Fahrenheit*/	\
				{										\
					CASE 0:		75.000;	/*linear*/		\
					CASE 1:		1112.000;				\
					CASE 2:		3308.000;				\
					CASE 3:		1832.000;				\
					CASE 4:		752.000; 				\
					CASE 5:		2498.000;				\
					CASE 6:		3200.000;				\
					CASE 7:		1652.000;				\
					CASE 8:		3200.000;				\
					CASE 9:		2192.000;				\
					CASE 10:	2192.000;				\
					CASE 11:	2372.000;				\
				}										\
			}


/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/

UNIT TempTCC_MB_ME_UNIT_RELATION 	// Temperatur C
{
	Loc_TempTC_MbMe_Unit:
	
	Loc_TempTCC_P1_Mb,
	Loc_TempTCC_P1_Me,
	Loc_TempTCC_P1_Vst
}

UNIT TempTCF_MB_ME_UNIT_RELATION 	// Temperatur F
{
	Loc_TempTC_MbMe_Unit:
	
	Loc_TempTCF_P1_Mb,
	Loc_TempTCF_P1_Me,
	Loc_TempTCF_P1_Vst
}

UNIT VoltTC_MB_ME_UNIT_RELATION 	// Voltage
{
	Loc_VoltTC_MbMe_Unit:
	
	Loc_VoltTC_P1_Mb,
	Loc_VoltTC_P1_Me
}

VARIABLE Loc_TempTC_MbMe_Unit
{
	LABEL		[unit];
	HELP		[unit_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 32;	
		{32,  [degC]	},										
		{33,  [degF]	}
	}
	PRE_EDIT_ACTIONS
	{
		DEFINITION
		{
			if (TempTC_P1_Option_Temperatur != 0)	
			{											
				Loc_TempTC_MbMe_Unit = 33;		// [degF]
			}											
			else 
			{											
				Loc_TempTC_MbMe_Unit = 32;		// [degC]
			}											
		}
	}
	POST_EDIT_ACTIONS
	{
		DEFINITION
		{
			if (Loc_TempTC_MbMe_Unit != 32)	
			{											
				TempTC_P1_Option_Temperatur = 1;	// [degF]
			}											
			else 
			{											
				TempTC_P1_Option_Temperatur = 0;	// [degC]
			}											
		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE Loc_VoltTC_MbMe_Unit
{
	LABEL		[unit];
	HELP		[unit_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 36;	
		{36,  [mV]		}
	}
	HANDLING	READ & WRITE;
}

/***********************************************************************/
/*    METHOD												           */
/***********************************************************************/

METHOD methode_set_TempTC_MbMe
{
	CLASS			INPUT;
	DEFINITION
	{
		if (SENSOR_TC_VOLT)
		{
			Loc_VoltTC_P1_Mb	= Loc_VoltTC_P1_Mb.DEFAULT_VALUE;
			Loc_VoltTC_P1_Me	= Loc_VoltTC_P1_Me.DEFAULT_VALUE;
			Loc_TempTCC_P1_Vst	= Loc_TempTCC_P1_Vst.DEFAULT_VALUE;
			Loc_TempTCF_P1_Vst	= Loc_TempTCF_P1_Vst.DEFAULT_VALUE;
		}
		else	if (SENSOR_TC_UNIT_C)
				{
					Loc_TempTCC_P1_Mb	= Loc_TempTCC_P1_Mb.DEFAULT_VALUE;
					Loc_TempTCC_P1_Me	= Loc_TempTCC_P1_Me.DEFAULT_VALUE;
				}
				else
				{
					Loc_TempTCF_P1_Mb	= Loc_TempTCF_P1_Mb.DEFAULT_VALUE;
					Loc_TempTCF_P1_Me	= Loc_TempTCF_P1_Me.DEFAULT_VALUE;
				}
	}
}
/*******************************************************************************/
/*****	Variables Kanal1 Index2	************************************************/
/*******************************************************************************/

TempTC_P1_Slot2		LIKE VARIABLE	P0_Slot0
{
}

TempTC_P1_Index2	LIKE VARIABLE	P0_Index0
{
	REDEFINE TYPE	UNSIGNED_INTEGER
	{
		DEFAULT_VALUE 2;
	}
}

VARIABLE	TempTC_P1_Mode
{
	LABEL		[P1_lin_type];
	HELP		[P1_lin_type_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 5;
		{ 0,	[linear]					}
		{ 1,	[thermoelement_U]			}
		{ 2,	[thermoelement_B]			}
		{ 3,	[thermoelement_E]			}
		{ 4,	[thermoelement_T]			}
		{ 5,	[thermoelement_K]			}
		{ 6,	[thermoelement_S]			}
		{ 7,	[thermoelement_R]			}
		{ 8,	[thermoelement_L]			}
		{ 9,	[thermoelement_J]			}
		{ 10,	[thermoelement_N]			}
		{ 11,	[thermoelement_Pallaplat]	}
	}
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		methode_set_TempTC_MbMe
	}
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_Option_Leitung
{
	LABEL		[P1_Option_Leitung];
	HELP		[P1_Option_Leitung_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1;
		{ 0,	[no]		},
		{ 1,	[yes]		}
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_Option_Vergleichstelle
{
	LABEL		[P1_Option_Vergleichstelle];
	HELP		[P1_Option_Vergleichstelle_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1;
		{	0x0000,	[intern_opt]	},
		{	0x0001,	[extern_opt]	}
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_Option_Temperatur
{
	LABEL		[unit];
	HELP		[unit_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 0;	
		{0,  [degC]	},
		{1,  [degF]	}
	}
	CLASS		CONTAINED;
	PRE_EDIT_ACTIONS
	{
		DEFINITION
		{
			if (Loc_TempTC_MbMe_Unit != 32)	
			{											
				TempTC_P1_Option_Temperatur = 1;	// [degF]
			}											
			else 
			{											
				TempTC_P1_Option_Temperatur = 0;	// [degC]
			}											
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_TC_TEMP)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_Option_Stoerunterdrueckung
{
	LABEL		[P1_Option_Stoerunterdrueckung];
	HELP		[P1_Option_Stoerunterdrueckung_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 0;
		{	0x0000,	[hz50]	},
		{	0x0001,	[hz60]	}
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_Option_Bit4_15
{
	LABEL		[P0_DUMMY];
	HELP		[P0_DUMMY_help];
	TYPE		UNSIGNED_INTEGER (2);
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}
/********** Skalierung *****************/

VARIABLE	TempTC_P1_ScalMb
{
	LABEL		[P1_ScalMb];
	HELP		[P1_ScalMb_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 10000;
	}
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		method_check_MbMe_int(TempTC_P1_ScalMb, TempTC_P1_ScalMe)
	}
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_ScalMe
{
	LABEL		[P1_ScalMe];
	HELP		[P1_ScalMe_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 50000;
	}
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		method_check_MbMe_int(TempTC_P1_ScalMb, TempTC_P1_ScalMe)
	}
	HANDLING	READ & WRITE;

}

VARIABLE	TempTC_P1_ScalOption
{
	LABEL		[P1_ScalOption];
	HELP		[P1_ScalOption_help];
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 0;
		{	0x00,	[ohne_status]	},
		{	0x01,	[mit_status]	}
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_LimLow
{
	LABEL		[P1_LimLow];
	HELP		[P1_LimLow_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 0;
	}
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		method_check_MbMe_int(TempTC_P1_LimLow, TempTC_P1_LimHigh)
	}
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_LimHigh
{
	LABEL		[P1_LimHigh];
	HELP		[P1_LimHigh_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 65535;
		DEFAULT_VALUE 60000;
	}	
	CLASS		CONTAINED;
	POST_EDIT_ACTIONS
	{
		method_check_MbMe_int(TempTC_P1_LimLow, TempTC_P1_LimHigh)
	}
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_Filter
{
	LABEL		[P1_Filter];
	HELP		[P1_Filter_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0;
		MAX_VALUE 1000;
		DEFAULT_VALUE 0;
	}
	
	CONSTANT_UNIT	[Percent_Second];
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

//********** Erweitert *****************/

VARIABLE	TempTCC_P1_Mb
{
	LABEL		[P1_Mb];
	HELP		[P1_Mb_help];
	TYPE		INTEGER (4)
	{
		DEFAULT_VALUE	0;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempTCC_P1_Mb
{
	LABEL		[P1_Mb];
	HELP		[P1_Mb_help];
	TYPE		FLOAT
	{
		MIN_VALUE		TempTC_MB_ME_MIN_VALUES;
		MAX_VALUE		TempTC_MB_ME_MAX_VALUES;
//		DEFAULT_VALUE	TempTC_CALC (0.0);
		DEFAULT_VALUE	TempTC_MB_ME_MIN_VALUES;
		DISPLAY_FORMAT ".3f";
	}
	CLASS			LOCAL;
	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_TC_TEMP && SENSOR_TC_UNIT_C)
		{
			method_scale1000_temp_C (MODUL_5y02, TempTCC_P1_Mb, Loc_TempTCC_P1_Mb)
		}
	}
	POST_EDIT_ACTIONS
	{
		IF (SENSOR_TC_TEMP && SENSOR_TC_UNIT_C)
		{
			method_rescale1000_temp_C (MODUL_5y02, TempTCC_P1_Mb, Loc_TempTCC_P1_Mb),
			method_check_MbMe_float(Loc_TempTCC_P1_Mb, Loc_TempTCC_P1_Me)
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_TC_TEMP && SENSOR_TC_UNIT_C)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTCF_P1_Mb
{
	LABEL		[P1_Mb];
	HELP		[P1_Mb_help];
	TYPE		INTEGER (4)
	{
		DEFAULT_VALUE	0;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempTCF_P1_Mb
{
	LABEL		[P1_Mb];
	HELP		[P1_Mb_help];
	TYPE		FLOAT
	{
		MIN_VALUE		TempTC_MB_ME_MIN_VALUES;
		MAX_VALUE		TempTC_MB_ME_MAX_VALUES;
//		DEFAULT_VALUE	TempTC_CALC (0.0);
		DEFAULT_VALUE	TempTC_MB_ME_MIN_VALUES;
		DISPLAY_FORMAT ".3f";
	}
	CLASS			LOCAL;
	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_TC_TEMP && SENSOR_TC_UNIT_F)
		{
			method_scale1000_temp_F (MODUL_5y02, TempTCF_P1_Mb, Loc_TempTCF_P1_Mb)
		}
	}
	POST_EDIT_ACTIONS
	{
		IF (SENSOR_TC_TEMP && SENSOR_TC_UNIT_F)
		{
			method_rescale1000_temp_F (MODUL_5y02, TempTCF_P1_Mb, Loc_TempTCF_P1_Mb),
			method_check_MbMe_float(Loc_TempTCF_P1_Mb, Loc_TempTCF_P1_Me)
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_TC_TEMP && SENSOR_TC_UNIT_F)
	HANDLING	READ & WRITE;
}

VARIABLE	VoltTC_P1_Mb
{
	LABEL		[P1_Mb];
	HELP		[P1_Mb_help];
	TYPE		INTEGER (4)
	{
		DEFAULT_VALUE	0;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_VoltTC_P1_Mb
{
	LABEL		[P1_Mb];
	HELP		[P1_Mb_help];
	TYPE		FLOAT
	{
		MIN_VALUE		VoltTC_CALC (-85.0);
		MAX_VALUE		VoltTC_CALC (85.0);
		DEFAULT_VALUE	VoltTC_CALC (-75.0);
//		MIN_VALUE		TempTC_MB_ME_MIN_VALUES;
//		MAX_VALUE		TempTC_MB_ME_MAX_VALUES;
//		DEFAULT_VALUE	TempTC_MB_ME_MIN_VALUES;
		DISPLAY_FORMAT ".3f";
	}
	CLASS			LOCAL;
	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_TC_VOLT)
		{
			method_scale1000_int_float (VoltTC_P1_Mb, Loc_VoltTC_P1_Mb)
		}
	}
	POST_EDIT_ACTIONS
	{
		IF (SENSOR_TC_VOLT)
		{
//			method_rescale1000_int_float (TempTC_P1_Mb, Loc_VoltTC_P1_Mb),
			method_rescale1000_int_float (VoltTC_P1_Mb, Loc_VoltTC_P1_Mb),
			method_check_MbMe_float(Loc_VoltTC_P1_Mb, Loc_VoltTC_P1_Me)
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_TC_VOLT)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTCC_P1_Me
{
	LABEL		[P1_Me];
	HELP		[P1_Me_help];
	TYPE		INTEGER (4)
	{
		DEFAULT_VALUE	100000;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempTCC_P1_Me
{
	LABEL		[P1_Me];
	HELP		[P1_Me_help];
	TYPE		FLOAT
	{
		MIN_VALUE		TempTC_MB_ME_MIN_VALUES;
		MAX_VALUE		TempTC_MB_ME_MAX_VALUES;
		DEFAULT_VALUE	TempTC_MB_ME_MAX_VALUES;
//		DEFAULT_VALUE	TempTC_CALC (100.0);
		DISPLAY_FORMAT ".3f";
	}
	CLASS			LOCAL;
	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_TC_TEMP && SENSOR_TC_UNIT_C)
		{
			method_scale1000_temp_C (MODUL_5y02, TempTCC_P1_Me, Loc_TempTCC_P1_Me)
		}
	}
	POST_EDIT_ACTIONS
	{
		IF (SENSOR_TC_TEMP && SENSOR_TC_UNIT_C)
		{
			method_rescale1000_temp_C (MODUL_5y02, TempTCC_P1_Me, Loc_TempTCC_P1_Me),
			method_check_MbMe_float(Loc_TempTCC_P1_Mb, Loc_TempTCC_P1_Me)
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_TC_TEMP && SENSOR_TC_UNIT_C)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTCF_P1_Me
{
	LABEL		[P1_Me];
	HELP		[P1_Me_help];
	TYPE		INTEGER (4)
	{
		DEFAULT_VALUE	100000;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempTCF_P1_Me
{
	LABEL		[P1_Me];
	HELP		[P1_Me_help];
	TYPE		FLOAT
	{
		MIN_VALUE		TempTC_MB_ME_MIN_VALUES;
		MAX_VALUE		TempTC_MB_ME_MAX_VALUES;
		DEFAULT_VALUE	TempTC_MB_ME_MAX_VALUES;
//		DEFAULT_VALUE	TempTC_CALC (100.0);
		DISPLAY_FORMAT ".3f";
	}
	CLASS			LOCAL;
	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_TC_TEMP && SENSOR_TC_UNIT_F)
		{
			method_scale1000_temp_F (MODUL_5y02, TempTCF_P1_Me, Loc_TempTCF_P1_Me)
		}
	}
	POST_EDIT_ACTIONS
	{
		IF (SENSOR_TC_TEMP && SENSOR_TC_UNIT_F)
		{
			method_rescale1000_temp_C (MODUL_5y02, TempTCF_P1_Me, Loc_TempTCF_P1_Me),
			method_check_MbMe_float(Loc_TempTCF_P1_Mb, Loc_TempTCF_P1_Me)
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_TC_TEMP && SENSOR_TC_UNIT_F)
	HANDLING	READ & WRITE;
}

VARIABLE	VoltTC_P1_Me
{
	LABEL		[P1_Me];
	HELP		[P1_Me_help];
	TYPE		INTEGER (4)
	{
		DEFAULT_VALUE	100000;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_VoltTC_P1_Me
{
	LABEL		[P1_Me];
	HELP		[P1_Me_help];
	TYPE		FLOAT
	{
		MIN_VALUE		VoltTC_CALC (-85.0);
		MAX_VALUE		VoltTC_CALC (85.0);
		DEFAULT_VALUE	VoltTC_CALC (75.0);
//		MIN_VALUE		TempTC_MB_ME_MIN_VALUES;
//		MAX_VALUE		TempTC_MB_ME_MAX_VALUES;
//		DEFAULT_VALUE	VoltTC_CALC (100.0);
		DISPLAY_FORMAT ".3f";
	}
	CLASS			LOCAL;
	PRE_EDIT_ACTIONS
	{
		IF (SENSOR_TC_VOLT)
		{
			method_scale1000_int_float (VoltTC_P1_Me, Loc_VoltTC_P1_Me)
		}
	}
	POST_EDIT_ACTIONS
	{
		IF (SENSOR_TC_VOLT)
		{
//			method_rescale1000_int_float (TempTC_P1_Me, Loc_VoltTC_P1_Me),
			method_rescale1000_int_float (VoltTC_P1_Me, Loc_VoltTC_P1_Me),
			method_check_MbMe_float(Loc_VoltTC_P1_Mb, Loc_VoltTC_P1_Me)
		}
	}
	VALIDITY	VALID_IF_TRUE (SENSOR_TC_VOLT)
	HANDLING	READ & WRITE;
}	

VARIABLE	TempTC_P1_R1
{
	LABEL		[P1_R1];
	HELP		[P1_R1_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempTC_P1_R1
{
	LABEL		[P1_R1];
	HELP		[P1_R1_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 0.00;
		MAX_VALUE 50.00;
		DEFAULT_VALUE 0.00;
	}	
	CONSTANT_UNIT	[Ohm];
	CLASS			LOCAL;
	VALIDITY	VALID_IF_TRUE (TempTC_P1_Option_Vergleichstelle == 0x0000)
	PRE_EDIT_ACTIONS
	{
		method_scale100_int_float (TempTC_P1_R1, Loc_TempTC_P1_R1)
	}
	POST_EDIT_ACTIONS
	{
		method_rescale100_int_float (TempTC_P1_R1, Loc_TempTC_P1_R1)
	}
	HANDLING		READ & WRITE;
}

VARIABLE	TempTC_P1_Pt1
{
	LABEL		[P1_FrqPt1];
	HELP		[P1_FrqPt1_help];
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 1;
		{ 1,	[off]				},
		{ 2,	[filter_aktiv1] 	},
		{ 3,	[filter_aktiv2] 	},
		{ 4,	[filter_aktiv3] 	},
		{ 5,	[filter_aktiv4]		}

	}
	CLASS		CONTAINED;
	VALIDITY	VALID_IF_TRUE (TempTC_P1_Option_Leitung == 1)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_Val
{
	LABEL		[P1_Val];
	HELP		[P1_Val_help];
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 3;
		{ 0,	"0"				},
		{ 1,	"0%" 			},
		{ 2,	"100%" 			},
		{ 3,	[letzten_wert1]	}

	}
	CLASS		CONTAINED;
	VALIDITY	VALID_IF_TRUE (TempTC_P1_Option_Leitung == 1)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_Tim
{
	LABEL		[P1_Tim];
	HELP		[P1_Tim_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 1;
		MAX_VALUE 250;
		DEFAULT_VALUE 10;
	}
	CLASS		CONTAINED;
	VALIDITY	VALID_IF_TRUE (TempTC_P1_Option_Leitung == 1)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTCC_P1_Vst
{
	LABEL		[P1_Vst];
	HELP		[P1_Vst_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	5000;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempTCC_P1_Vst
{
	LABEL		[P1_Vst];
	HELP		[P1_Vst_help];
	TYPE		FLOAT
	{
		MIN_VALUE		TempTC_CALC (0.00);
		MAX_VALUE		TempTC_CALC (100.00);
		DEFAULT_VALUE	TempTC_CALC (50.00);
		DISPLAY_FORMAT	".2f";
	}	
	CLASS		LOCAL;
	PRE_EDIT_ACTIONS
	{
		method_scale100_temp_C (MODUL_5y02, TempTCC_P1_Vst, Loc_TempTCC_P1_Vst)
	}
	POST_EDIT_ACTIONS
	{
		method_rescale100_temp_C (MODUL_5y02, TempTCC_P1_Vst, Loc_TempTCC_P1_Vst)
	}
	VALIDITY	VALID_IF_TRUE ((TempTC_P1_Option_Vergleichstelle == 0x0001) && SENSOR_TC_UNIT_C)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTCF_P1_Vst
{
	LABEL		[P1_Vst];
	HELP		[P1_Vst_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	5000;
	}
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
}

VARIABLE	Loc_TempTCF_P1_Vst
{
	LABEL		[P1_Vst];
	HELP		[P1_Vst_help];
	TYPE		FLOAT
	{
		MIN_VALUE		TempTC_CALC (0.00);
		MAX_VALUE		TempTC_CALC (100.00);
		DEFAULT_VALUE	TempTC_CALC (50.00);
		DISPLAY_FORMAT	".2f";
	}	
	CLASS		LOCAL;
	PRE_EDIT_ACTIONS
	{
		method_scale100_temp_F (MODUL_5y02, TempTCF_P1_Vst, Loc_TempTCF_P1_Vst)
	}
	POST_EDIT_ACTIONS
	{
		method_rescale100_temp_F (MODUL_5y02, TempTCF_P1_Vst, Loc_TempTCF_P1_Vst)
	}
	VALIDITY	VALID_IF_TRUE ((TempTC_P1_Option_Vergleichstelle == 0x0001) && SENSOR_TC_UNIT_F)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_Tast
{
	LABEL		[P1_Tast];
	HELP		[P1_Tast_help];
	TYPE		UNSIGNED_INTEGER (2)
	{
		MIN_VALUE 1;
		MAX_VALUE 250;
		DEFAULT_VALUE 1;
	}
	
	CLASS		CONTAINED;
	VALIDITY	VALID_IF_TRUE (TempTC_P1_Option_Vergleichstelle == 0x0001)
	HANDLING	READ & WRITE;
}

VARIABLE	TempTC_P1_DUMMY2
{
	LABEL		[P0_DUMMY];
	HELP		[P0_DUMMY_help];
	TYPE		ASCII (28);
	CLASS		CONTAINED;
	HANDLING	READ;
}

/*******************************************************************************/
/*****	COMMAND				*****************************************************/
/*******************************************************************************/

#define	DOWNLOAD_TempTC								\
			P0_Type,								\
			P0_Slot0,								\
			P0_Index0,								\
			P0_Tag,									\
			P0_Channel,								\
			P0_Sector,								\
			P0_Option,								\
/*			P0_Time,								\
*/			P0_Revision,							\
			P0_Size,								\
			P0_CfgMode,					\
			Mod4y5y_P1_Slot1,						\
			Mod4y5y_P1_Index1,						\
			Mod4y5y_P1_Tag,							\
			Mod4y5y_P1_State,						\
			Mod4y5y_P1_ErrMode,						\
			Mod4y5y_P1_SimVal,						\
			Mod4y5y_P1_SimState_Data,				\
			Mod4y5y_P1_SimOption,					\
			Mod4y5y_P1_ErrVal,						\
			Mod4y5y_P1_ErrState_Data,				\
			Mod4y5y_P1_ErrOption,					\
			TempTC_P1_Slot2,						\
			TempTC_P1_Index2,						\
			TempTC_P1_Mode,							\
			TempTC_P1_Option_Leitung,				\
			TempTC_P1_Option_Vergleichstelle,		\
			TempTC_P1_Option_Temperatur,			\
			TempTC_P1_Option_Stoerunterdrueckung,	\
			TempTC_P1_ScalMb,						\
			TempTC_P1_ScalMe,						\
			TempTC_P1_ScalOption,					\
			TempTC_P1_LimLow,						\
			TempTC_P1_LimHigh, 						\
			TempTC_P1_Filter,						\
			TempTCC_P1_Mb,							\
			TempTCC_P1_Me,							\
			TempTC_P1_R1,							\
			TempTC_P1_Pt1,							\
			TempTC_P1_Val,							\
			TempTC_P1_Tim,							\
			TempTCC_P1_Vst,							\
			TempTC_P1_Tast


#define	UPLOAD_TempTC		DOWNLOAD_TempTC


COMMAND read_TempTC_index2
{
	SLOT		Loc_P0_Slot0;
	INDEX		2;
	OPERATION	READ;
	TRANSACTION
	{
		REQUEST
		{			
		}
		REPLY
		{
			TempTC_P1_Slot2, 
			TempTC_P1_Index2, 
			TempTC_P1_Mode,
			TempTC_P1_Option_Bit4_15				<0xFFF0>, 
			TempTC_P1_Option_Stoerunterdrueckung	<0x0008>,
			TempTC_P1_Option_Temperatur				<0x0004>, 
			TempTC_P1_Option_Vergleichstelle		<0x0002>,
			TempTC_P1_Option_Leitung				<0x0001>, 
			TempTC_P1_ScalMb, 
			TempTC_P1_ScalMe,
			Bit1_15									<0xFFFE>,
			TempTC_P1_ScalOption					<0x0001>, 
			TempTC_P1_LimLow, 
			TempTC_P1_LimHigh,
			TempTC_P1_Filter, 
			TempTCC_P1_Mb, 
			TempTCC_P1_Me, 
			TempTC_P1_R1, 
			TempTC_P1_Pt1,
			TempTC_P1_Val, 
			TempTC_P1_Tim, 
			TempTCC_P1_Vst, 
			TempTC_P1_Tast, 
			TempTC_P1_DUMMY2
		}
	}
}

COMMAND write_TempTC_index2
{
	SLOT		Loc_P0_Slot0;
	INDEX		2;
	OPERATION	WRITE;
	TRANSACTION
	{
		REQUEST
		{
			TempTC_P1_Slot2, 
			TempTC_P1_Index2, 
			TempTC_P1_Mode,
			TempTC_P1_Option_Bit4_15				<0xFFF0>, 
			TempTC_P1_Option_Stoerunterdrueckung	<0x0008>,
			TempTC_P1_Option_Temperatur				<0x0004>, 
			TempTC_P1_Option_Vergleichstelle		<0x0002>,
			TempTC_P1_Option_Leitung				<0x0001>, 
			TempTC_P1_ScalMb, 
			TempTC_P1_ScalMe,
			Bit1_15									<0xFFFE>,
			TempTC_P1_ScalOption					<0x0001>, 
			TempTC_P1_LimLow, 
			TempTC_P1_LimHigh,
			TempTC_P1_Filter, 
			TempTCC_P1_Mb, 
			TempTCC_P1_Me, 
			TempTC_P1_R1, 
			TempTC_P1_Pt1,
			TempTC_P1_Val, 
			TempTC_P1_Tim, 
			TempTCC_P1_Vst, 
			TempTC_P1_Tast, 
			0, 0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0, 0, 0, 0, 0,		 // TempTC_P1_DUMMY2
			0, 0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0					 // TempTC_P1_DUMMY2
		}
		REPLY
		{
		}
	}
}


/*******************************************************************************/
/*****	Table: Specialist  *****************************************************/
/*******************************************************************************/

MENU Tab_s_TempTC_kanal1
{
	LABEL		[menu_kanal1];
	ACCESS		OFFLINE;
	ITEMS
	{
		Tab_s_TempTC_ident_k1,
		Tab_s_TempTC_input_k1
	}
}

MENU Tab_s_TempTC_ident_k1
{
	LABEL		[menu_ident];
	ACCESS		OFFLINE;
	ITEMS
	{
		Mod4y5y_P1_Tag
	}
}

MENU Tab_s_TempTC_input_k1
{
	LABEL		[menu_input];
	ACCESS		OFFLINE;
	ITEMS
	{
		Mod4y5y_P1_State,
		Mod4y5y_P1_ErrMode,	
		TempTC_P1_Filter,
//		TempTC_P1_LimLow					(READ_ONLY),
//		TempTC_P1_LimHigh					(READ_ONLY),
		TempTC_P1_LimLow,
		TempTC_P1_LimHigh,
		Tab_s_TempTC_input_simulation,
		Tab_s_TempTC_input_ersatzwert,
		Tab_s_TempTC_input_skal,
		Tab_s_TempTC_input_lfd,
		Tab_s_TempTC_input_messumformer
	}
}

MENU Tab_s_TempTC_input_simulation
{
	LABEL		[simulation];
	ACCESS		OFFLINE;
	ITEMS
	{
		Loc_Mod4y5y_P1_SimVal,
		Mod4y5y_P1_SimOption,
		Mod4y5y_P1_SimState_Data
	}
	VALIDITY	VALID_IF_TRUE (Mod4y5y_P1_State == 1)
}

MENU Tab_s_TempTC_input_ersatzwert
{
	LABEL		[ersatzwert];
	ACCESS		OFFLINE;
	ITEMS
	{
		Loc_Mod4y5y_P1_ErrVal,
		Mod4y5y_P1_ErrOption,
		Mod4y5y_P1_ErrState_Data			(READ_ONLY)
	}
	VALIDITY	VALID_IF_TRUE (Mod4y5y_P1_ErrMode == 1)
}

MENU Tab_s_TempTC_input_skal
{
	LABEL		[skalierung_in_bit_0_65535];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempTC_P1_ScalOption,
		TempTC_P1_ScalMb,
		TempTC_P1_ScalMe,
	}
}

MENU Tab_s_TempTC_input_lfd
{
	LABEL		[leitungsueberwachung];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempTC_P1_Option_Leitung,
		TempTC_P1_Pt1,
		TempTC_P1_Val,
		TempTC_P1_Tim
	}
}

MENU Tab_s_TempTC_input_messumformer
{
	LABEL		[messumformer];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempTC_P1_Mode,
		TempTC_P1_Option_Vergleichstelle,
		Loc_TempTCC_P1_Vst,
		Loc_TempTCF_P1_Vst,
		Loc_TempTC_P1_R1,
		TempTC_P1_Option_Stoerunterdrueckung,
		TempTC_P1_Tast,
		Loc_TempTC_MbMe_Unit,
		Loc_TempTCC_P1_Mb,
		Loc_TempTCC_P1_Me,
		Loc_TempTCF_P1_Mb,
		Loc_TempTCF_P1_Me,
		Loc_VoltTC_P1_Mb,
		Loc_VoltTC_P1_Me
	}
}


/*******************************************************************************/
/*****	Table: Maintenance   *****************************************************/
/*******************************************************************************/

MENU Tab_m_TempTC_kanal1
{
	LABEL		[menu_kanal1];
	ACCESS		OFFLINE;
	ITEMS
	{
		Tab_m_TempTC_ident_k1,
		Tab_m_TempTC_input_k1
	}
}

MENU Tab_m_TempTC_ident_k1
{
	LABEL		[menu_ident];
	ACCESS		OFFLINE;
	ITEMS
	{
		Mod4y5y_P1_Tag
	}
}

MENU Tab_m_TempTC_input_k1
{
	LABEL		[menu_input];
	ACCESS		OFFLINE;
	ITEMS
	{
		Mod4y5y_P1_State					(READ_ONLY),
		Mod4y5y_P1_ErrMode					(READ_ONLY),
		TempTC_P1_Filter					(READ_ONLY),
		TempTC_P1_LimLow					(READ_ONLY),
		TempTC_P1_LimHigh					(READ_ONLY),
		Tab_m_TempTC_input_simulation,
		Tab_m_TempTC_input_ersatzwert,
		Tab_m_TempTC_input_skal,
		Tab_m_TempTC_input_lfd,
		Tab_m_TempTC_input_messumformer
	}
}

MENU Tab_m_TempTC_input_simulation
{
	LABEL		[simulation];
	ACCESS		OFFLINE;
	ITEMS
	{
		Loc_Mod4y5y_P1_SimVal				(READ_ONLY),
		Mod4y5y_P1_SimOption				(READ_ONLY),
		Mod4y5y_P1_SimState_Data			(READ_ONLY)
	}
	VALIDITY	VALID_IF_TRUE (Mod4y5y_P1_State == 1)
}

MENU Tab_m_TempTC_input_ersatzwert
{
	LABEL		[ersatzwert];
	ACCESS		OFFLINE;
	ITEMS
	{
		Loc_Mod4y5y_P1_ErrVal				(READ_ONLY),
		Mod4y5y_P1_ErrOption				(READ_ONLY),
		Mod4y5y_P1_ErrState_Data			(READ_ONLY)
	}
	VALIDITY	VALID_IF_TRUE (Mod4y5y_P1_ErrMode == 1)
}

MENU Tab_m_TempTC_input_skal
{
	LABEL		[skalierung_in_bit_0_65535];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempTC_P1_ScalOption				(READ_ONLY),
		TempTC_P1_ScalMb					(READ_ONLY),
		TempTC_P1_ScalMe					(READ_ONLY)
	}
}

MENU Tab_m_TempTC_input_lfd
{
	LABEL		[leitungsueberwachung];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempTC_P1_Option_Leitung			(READ_ONLY),
		TempTC_P1_Pt1						(READ_ONLY),
		TempTC_P1_Val						(READ_ONLY),
		TempTC_P1_Tim						(READ_ONLY)
	}									
}

MENU Tab_m_TempTC_input_messumformer
{
	LABEL		[messumformer];
	ACCESS		OFFLINE;
	ITEMS
	{
		TempTC_P1_Mode							(READ_ONLY),
		TempTC_P1_Option_Vergleichstelle		(READ_ONLY),
		Loc_TempTCC_P1_Vst						(READ_ONLY),
		Loc_TempTCF_P1_Vst						(READ_ONLY),
		Loc_TempTC_P1_R1						(READ_ONLY),
		TempTC_P1_Option_Stoerunterdrueckung	(READ_ONLY),
		TempTC_P1_Tast							(READ_ONLY),
		Loc_TempTC_MbMe_Unit					(READ_ONLY),
		Loc_TempTCC_P1_Mb						(READ_ONLY),
		Loc_TempTCC_P1_Me						(READ_ONLY),
		Loc_VoltTC_P1_Mb						(READ_ONLY),
		Loc_VoltTC_P1_Me						(READ_ONLY),
		Loc_TempTCF_P1_Mb						(READ_ONLY),
		Loc_TempTCF_P1_Me						(READ_ONLY)
	}
}